pycocoa.internals.frozendict

Package pycocoa :: Module internals :: Class frozendict |
[frames] | no frames]

# Class frozendict

     object --+
              |
           dict --+
                  |
    _frozendictbase --+
                      |
                     frozendict

An immutable Python `dict` with key and attribute access to the items.

See Also: Frozen Dictionaries

Instance Methods
    new empty dictionary
__init__(self, *args, **kwds) New `frozendict`. |
__getattr__(self, name) Get the value of an attribute or item by `name`. |
Inherited from `_frozendictbase`: `__hash__` Inherited from `dict`: `__cmp__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__repr__`, `__sizeof__`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, *args, **kwds) Ero Carrera's extended version of `frozendict`. |

Properties
Inherited from `_frozendictbase`: `__call__`, `__delitem__`, `__setitem__`, `clear`, `pop`, `popitem`, `setdefault`, `update` Inherited from `object`: `__class__`

Method Details

### __new__(cls, *args, **kwds) Static Method |
Ero Carrera's extended version of `frozendict`. Returns: a new object with type S, a subtype of T Overrides: object.__new__

### __init__(self, *args, **kwds) (Constructor) |
New `frozendict`. Returns:
    new empty dictionary
Overrides: object.__init__